@@ -8,8 +8,9 @@ from .topic import scrape_topic
 from .keyword_api import scrape_keyword_with_api
 from .profile_details import get_profile_details
 from .topic_api import scrape_topic_with_api
+from .profile_api import scrape_profile_with_api
 # __all__ = ["Initializer",
 #           "Utilities", "Finder",
 #           "Scraping_utilities","scrap_profile","scrap_keyword"]
 __all__ = ["scrape_profile", "scrape_keyword",
-           "scrape_topic", "scrape_keyword_with_api", "get_profile_details", "scrape_topic_with_api"]
+           "scrape_topic", "scrape_keyword_with_api", "get_profile_details", "scrape_topic_with_api", "scrape_profile_with_api"]
