@@ -99,7 +99,7 @@ def scrape_keyword_with_api(query: str, proxy: Union[str, None] = None,
     """
     keyword_scraper = Keywords_api(query, proxy, tweets_count)
     data = keyword_scraper.scrap()
-    if output_filename:
+    if output_filename and len(data) > 0:
         path = os.path.join(output_dir, "{}.json".format(output_filename))
         mode = 'a'
         if os.path.exists(path):
@@ -114,8 +114,8 @@ def scrape_keyword_with_api(query: str, proxy: Union[str, None] = None,
                     content = {}
                 file.close()
                 data.update(content)
-                with open(path, 'w', encoding='utf-8') as file_in_write_mode:
-                    json.dump(data, file_in_write_mode)
-                    logger.info('Data was saved to {}'.format(path))
+        with open(path, 'w', encoding='utf-8') as file_in_write_mode:
+            json.dump(data, file_in_write_mode)
+            logger.info('Data was saved to {}'.format(path))
     else:
         return data
